@@ -34,12 +34,14 @@ func diffCmd(ctx *config.RunContext) *cobra.Command {
 
 			err = checkRunConfig(cmd.ErrOrStderr(), ctx.Config)
 			if err != nil {
-				ui.PrintUsageErrorAndExit(cmd, err.Error())
+				ui.PrintUsage(cmd)
+				return err
 			}
 
 			err = checkDiffConfig(ctx.Config)
 			if err != nil {
-				ui.PrintUsageErrorAndExit(cmd, err.Error())
+				ui.PrintUsage(cmd)
+				return err
 			}
 
 			ctx.Config.Format = "diff"
