@@ -107,6 +107,8 @@ func (c *RunContext) loadInitialContextValues() {
 	c.SetContextValue("os", runtime.GOOS)
 	c.SetContextValue("ciPlatform", ciPlatform())
 	c.SetContextValue("ciScript", ciScript())
+	c.SetContextValue("ciPostCondition", os.Getenv("INFRACOST_CI_POST_CONDITION"))
+	c.SetContextValue("ciPercentageThreshold", os.Getenv("INFRACOST_CI_PERCENTAGE_THRESHOLD"))
 }
 
 func baseVersion(v string) string {
