@@ -32,21 +32,27 @@ func (p *PlanJSONProvider) AddMetadata(metadata *schema.ProjectMetadata) {
 	// no op
 }
 
-func (p *PlanJSONProvider) LoadResources(project *schema.Project, usage map[string]*schema.UsageData) error {
+func (p *PlanJSONProvider) LoadResources(usage map[string]*schema.UsageData) ([]*schema.Project, error) {
 	j, err := ioutil.ReadFile(p.Path)
 	if err != nil {
-		return errors.Wrap(err, "Error reading Terraform plan JSON file")
+		return []*schema.Project{}, errors.Wrap(err, "Error reading Terraform plan JSON file")
 	}
 
+	metadata := config.DetectProjectMetadata(p.ctx.ProjectConfig.Path)
+	metadata.Type = p.Type()
+	p.AddMetadata(metadata)
+	name := schema.GenerateProjectName(metadata, p.ctx.RunContext.Config.EnableDashboard)
+
+	project := schema.NewProject(name, metadata)
 	parser := NewParser(p.ctx)
 
 	pastResources, resources, err := parser.parseJSON(j, usage)
 	if err != nil {
-		return errors.Wrap(err, "Error parsing Terraform plan JSON file")
+		return []*schema.Project{project}, errors.Wrap(err, "Error parsing Terraform plan JSON file")
 	}
 
 	project.PastResources = pastResources
 	project.Resources = resources
 
-	return nil
+	return []*schema.Project{project}, nil
 }
